@@ -1,25 +1,21 @@
-
 import matplotlib.pyplot as plt
 import numpy as np
+import plotly.graph_objects as go
 import pynwb
 import scipy
-from ipywidgets import widgets, fixed, FloatProgress
+from ipywidgets import widgets, fixed, FloatProgress, Layout
 from matplotlib.collections import PatchCollection
 from matplotlib.patches import Rectangle
 from pynwb.misc import AnnotationSeries, Units, DecompositionSeries
 
+from .analysis.spikes import compute_smoothed_firing_rate
 from .controllers import make_trial_event_controller, GroupAndSortController, StartAndDurationController, ProgressBar
 from .utils.dynamictable import infer_categorical_columns
+from .utils.mpl import create_big_ax
+from .utils.plotly import event_group
 from .utils.units import get_spike_times, get_max_spike_time, get_min_spike_time, align_by_time_intervals, \
     get_unobserved_intervals
-from .utils.mpl import create_big_ax
 from .utils.widgets import interactive_output
-from .analysis.spikes import compute_smoothed_firing_rate
-from .utils.plotly import event_group, Peakaboo
-import plotly.graph_objects as go
-
-
-from ipywidgets import Layout
 
 color_wheel = plt.rcParams['axes.prop_cycle'].by_key()['color']
 
@@ -98,15 +94,14 @@ class RasterWidget(widgets.HBox):
         if foreign_time_window_controller is None:
             self.tmin = get_min_spike_time(units)
             self.tmax = get_max_spike_time(units)
-            self.time_window_controller = StartAndDurationController(tmin=self.tmin, tmax=self.tmax, start=self.tmin,
-                                                                     duration=5)
+            self.time_window_controller = StartAndDurationController(tmin=self.tmin, tmax=self.tmax)
         else:
             self.time_window_controller = foreign_time_window_controller
 
         if foreign_group_and_sort_controller:
             self.gas = foreign_group_and_sort_controller
         else:
-            self.gas = self.make_group_and_sort(group_by=group_by)
+            self.gas = self.make_group_and_sort(group_by=group_by, control_order=False)
 
         self.progress_bar = widgets.HBox()
 
@@ -129,26 +124,26 @@ class RasterWidget(widgets.HBox):
             )
         else:
             right_panel = widgets.VBox(
-                        children=[
-                            self.time_window_controller,
-                            self.progress_bar,
-                            out_fig,
-                        ],
-                        layout=Layout(width="100%")
-                    )
+                children=[
+                    self.time_window_controller,
+                    self.progress_bar,
+                    out_fig,
+                ],
+                layout=Layout(width="100%")
+            )
 
         if foreign_group_and_sort_controller:
             self.children = [right_panel]
         else:
             self.children = [
-                    self.gas,
-                    right_panel
-                ]
+                self.gas,
+                right_panel
+            ]
 
         self.layout = Layout(width="100%")
 
-    def make_group_and_sort(self, group_by=None):
-        return GroupAndSortController(self.units, group_by=group_by)
+    def make_group_and_sort(self, group_by=None, control_order=True):
+        return GroupAndSortController(self.units, group_by=group_by, control_order=control_order)
 
 
 def show_decomposition_series(node, **kwargs):
@@ -167,7 +162,7 @@ def show_decomposition_series(node, **kwargs):
                                min_height='30px', min_width='130px')
     vbox = []
     for key, val in node.fields.items():
-        lbl_key = widgets.Label(key+':', layout=field_lay)
+        lbl_key = widgets.Label(key + ':', layout=field_lay)
         lbl_val = widgets.Label(str(val), layout=field_lay)
         vbox.append(widgets.HBox(children=[lbl_key, lbl_val]))
     children[0] = widgets.VBox(vbox)
@@ -185,17 +180,17 @@ def show_decomposition_traces(node: DecompositionSeries):
     def control_plot(x0, x1, ch0, ch1):
         fig, ax = plt.subplots(nrows=nBands, ncols=1, sharex=True, figsize=(14, 7))
         for bd in range(nBands):
-            data = node.data[x0:x1, ch0:ch1+1, bd]
+            data = node.data[x0:x1, ch0:ch1 + 1, bd]
             xx = np.arange(x0, x1)
             mu_array = np.mean(data, 0)
             sd_array = np.std(data, 0)
             offset = np.mean(sd_array) * 5
-            yticks = [i*offset for i in range(ch1+1-ch0)]
-            for i in range(ch1+1-ch0):
+            yticks = [i * offset for i in range(ch1 + 1 - ch0)]
+            for i in range(ch1 + 1 - ch0):
                 ax[bd].plot(xx, data[:, i] - mu_array[i] + yticks[i])
             ax[bd].set_ylabel('Ch #', fontsize=20)
             ax[bd].set_yticks(yticks)
-            ax[bd].set_yticklabels([str(i) for i in range(ch0, ch1+1)])
+            ax[bd].set_yticklabels([str(i) for i in range(ch0, ch1 + 1)])
             ax[bd].tick_params(axis='both', which='major', labelsize=16)
         ax[bd].set_xlabel('Time [ms]', fontsize=20)
         return fig
@@ -208,12 +203,12 @@ def show_decomposition_traces(node: DecompositionSeries):
     # Controls
     field_lay = widgets.Layout(max_height='40px', max_width='100px',
                                min_height='30px', min_width='70px')
-    x0 = widgets.BoundedIntText(value=0, min=0, max=int(1000*nSamples/fs-100),
+    x0 = widgets.BoundedIntText(value=0, min=0, max=int(1000 * nSamples / fs - 100),
                                 layout=field_lay)
-    x1 = widgets.BoundedIntText(value=nSamples, min=100, max=int(1000*nSamples/fs),
+    x1 = widgets.BoundedIntText(value=nSamples, min=100, max=int(1000 * nSamples / fs),
                                 layout=field_lay)
-    ch0 = widgets.BoundedIntText(value=0, min=0, max=int(nChannels-1), layout=field_lay)
-    ch1 = widgets.BoundedIntText(value=10, min=0, max=int(nChannels-1), layout=field_lay)
+    ch0 = widgets.BoundedIntText(value=0, min=0, max=int(nChannels - 1), layout=field_lay)
+    ch1 = widgets.BoundedIntText(value=10, min=0, max=int(nChannels - 1), layout=field_lay)
 
     controls = {
         'x0': x0,
@@ -250,13 +245,15 @@ class PSTHWidget(widgets.VBox):
 
         if unit_controller is None:
             nunits = len(units['spike_times'].data)
-            unit_controller = widgets.Dropdown(options=[x for x in range(nunits)], value=unit_index, description='unit')
+            unit_controller = widgets.Dropdown(options=[x for x in range(nunits)], value=unit_index,
+                                               description='unit',
+                                               layout=Layout(width='200px'))
 
-        trial_event_controller = make_trial_event_controller(self.trials)
-        before_slider = widgets.FloatSlider(.5, min=0, max=5., description='before (s)', continuous_update=False)
-        after_slider = widgets.FloatSlider(2., min=0, max=5., description='after (s)', continuous_update=False)
+        trial_event_controller = make_trial_event_controller(self.trials, layout=Layout(width='200px'))
+        before_ft = widgets.FloatText(.5, min=0, description='before (s)', layout=Layout(width='200px'))
+        after_ft = widgets.FloatText(2., min=0, description='after (s)', layout=Layout(width='200px'))
 
-        self.gas = self.make_group_and_sort(window=False)
+        self.gas = self.make_group_and_sort(window=False, control_order=False)
 
         self.controls = dict(
             units=fixed(units),
@@ -264,11 +261,11 @@ class PSTHWidget(widgets.VBox):
             sigma_in_secs=fixed(sigma_in_secs),
             ntt=fixed(ntt),
             index=unit_controller,
-            after=after_slider,
-            before=before_slider,
+            after=after_ft,
+            before=before_ft,
             start_label=trial_event_controller,
             gas=self.gas,
-            #progress_bar=fixed(progress_bar)
+            # progress_bar=fixed(progress_bar)
         )
 
         out_fig = interactive_output(trials_psth, self.controls)
@@ -279,8 +276,8 @@ class PSTHWidget(widgets.VBox):
                 widgets.VBox([
                     unit_controller,
                     trial_event_controller,
-                    before_slider,
-                    after_slider,
+                    before_ft,
+                    after_ft,
                 ])
             ]),
             out_fig
@@ -289,13 +286,14 @@ class PSTHWidget(widgets.VBox):
     def get_trials(self):
         return self.units.get_ancestor('NWBFile').trials
 
-    def make_group_and_sort(self, window=None):
-        return GroupAndSortController(self.trials, window=window)
+    def make_group_and_sort(self, window=None, control_order=False):
+        return GroupAndSortController(self.trials, window=window, control_order=control_order)
 
 
 def trials_psth(units: pynwb.misc.Units, index, start_label='start_time',
                 before=0., after=1., order=None, group_inds=None, labels=None,
-                sigma_in_secs=0.05, ntt=1000, progress_bar=None, trials=None):
+                sigma_in_secs=0.05, ntt=1000, progress_bar=None, trials=None,
+                figsize=(7, 7)):
     """
 
     Parameters
@@ -316,6 +314,9 @@ def trials_psth(units: pynwb.misc.Units, index, start_label='start_time',
         standard deviation of gaussian kernel
     ntt:
         Number of time points to use for smooth curve
+    progress_bar:
+    trials:
+    figsize: tuple, optional
 
     Returns
     -------
@@ -334,7 +335,7 @@ def trials_psth(units: pynwb.misc.Units, index, start_label='start_time',
                                             order,
                                             progress_bar=progress_bar)
 
-    fig, axs = plt.subplots(2, 1, figsize=(10, 10))
+    fig, axs = plt.subplots(2, 1, figsize=figsize)
 
     show_psth_raster(data, before, after, group_inds, labels, ax=axs[0], progress_bar=progress_bar)
 
@@ -349,23 +350,26 @@ def trials_psth(units: pynwb.misc.Units, index, start_label='start_time',
 
 def show_psth_smoothed(data, ax, before, after, group_inds=None, sigma_in_secs=.05, ntt=1000,
                        align_line_color=(.7, .7, .7)):
-
-    all_data = np.hstack(data)
-    if not len(all_data):
+    if not len(data):  # TODO: when does this occur?
         return
+    all_data = np.hstack(data)
     tt = np.linspace(min(all_data), max(all_data), ntt)
     smoothed = np.array([compute_smoothed_firing_rate(x, tt, sigma_in_secs) for x in data])
 
     if group_inds is None:
-        group_inds = np.zeros((len(smoothed)))
+        group_inds = np.zeros((len(smoothed)), dtype=np.int)
     group_stats = []
-    for group in range(len(np.unique(group_inds))):
+    for group in np.unique(group_inds):
         this_mean = np.mean(smoothed[group_inds == group], axis=0)
         err = scipy.stats.sem(smoothed[group_inds == group], axis=0)
-        group_stats.append({'mean': this_mean,
-                            'lower': this_mean - 2 * err,
-                            'upper': this_mean + 2 * err})
-    for stats, color in zip(group_stats, color_wheel):
+        group_stats.append(
+            dict(mean=this_mean,
+                 lower=this_mean - 2 * err,
+                 upper=this_mean + 2 * err,
+                 group=group)
+        )
+    for stats in group_stats:
+        color = color_wheel[stats['group']]
         ax.plot(tt, stats['mean'], color=color)
         ax.fill_between(tt, stats['lower'], stats['upper'], alpha=.2, color=color)
     ax.set_xlim([-before, after])
@@ -376,7 +380,8 @@ def show_psth_smoothed(data, ax, before, after, group_inds=None, sigma_in_secs=.
 
 
 def plot_grouped_events(data, window, group_inds=None, colors=color_wheel, ax=None, labels=None,
-                        show_legend=True, offset=0, unobserved_intervals_list=None, progress_bar=None):
+                        show_legend=True, offset=0, unobserved_intervals_list=None, progress_bar=None,
+                        figsize=(8, 6)):
     """
 
     Parameters
@@ -392,6 +397,7 @@ def plot_grouped_events(data, window, group_inds=None, colors=color_wheel, ax=No
     offset: number, optional
     unobserved_intervals_list: array-like, optional
     progress_bar: FloatProgress, optional
+    figsize: tuple, optional
 
     Returns
     -------
@@ -401,7 +407,7 @@ def plot_grouped_events(data, window, group_inds=None, colors=color_wheel, ax=No
     data = np.asarray(data)
     legend_kwargs = dict()
     if ax is None:
-        fig, ax = plt.subplots(figsize=(9.7, 7))
+        fig, ax = plt.subplots(figsize=figsize)
         if hasattr(fig, 'canvas'):
             fig.canvas.header_visible = False
         else:
@@ -438,6 +444,7 @@ def plot_grouped_events(data, window, group_inds=None, colors=color_wheel, ax=No
     ax.set_ylim(np.array([-.5, len(data) - .5]) + offset)
     if len(data) <= 30:
         ax.set_yticks(range(offset, len(data) + offset))
+        ax.set_yticklabels(range(offset, len(data) + offset))
 
     return ax
 
@@ -573,7 +580,7 @@ class RasterGridWidget(widgets.VBox):
         else:
             self.trials = trials
 
-        groups = list(self.trials.colnames)
+        groups = self.get_groups()
 
         rows_controller = widgets.Dropdown(options=[None] + list(groups), description='rows')
         cols_controller = widgets.Dropdown(options=[None] + list(groups), description='cols')
@@ -634,9 +641,8 @@ class RasterGridWidget(widgets.VBox):
 
 
 def plot_grouped_events_plotly(data, window=None, group_inds=None, colors=color_wheel, labels=None,
-                               show_legend=True, unobserved_intervals_list=None, progress_bar=None, fig=None):
-
-    data = np.array(data)
+                               show_legend=True, unobserved_intervals_list=None, progress_bar=None, fig=None, **kwargs):
+    data = np.array(data, dtype=object)
 
     if fig is None:
         fig = go.FigureWidget()
@@ -651,11 +657,12 @@ def plot_grouped_events_plotly(data, window=None, group_inds=None, colors=color_
                         offset=offset,
                         label=labels[ui],
                         color=color,
-                        fig=fig)
+                        fig=fig,
+                        **kwargs)
             offset += len(this_data)
 
     else:
-        event_group(data, fig=fig)
+        event_group(data, fig=fig, **kwargs)
 
     fig.update_layout(xaxis_title="time (s)")
 
@@ -675,8 +682,7 @@ class RasterWidgetPlotly(widgets.HBox):
         if foreign_time_window_controller is None:
             self.tmin = get_min_spike_time(units)
             self.tmax = get_max_spike_time(units)
-            self.time_window_controller = StartAndDurationController(tmin=self.tmin, tmax=self.tmax, start=self.tmin,
-                                                                     duration=5)
+            self.time_window_controller = StartAndDurationController(tmin=self.tmin, tmax=self.tmax)
         else:
             self.time_window_controller = foreign_time_window_controller
 
@@ -705,21 +711,21 @@ class RasterWidgetPlotly(widgets.HBox):
             )
         else:
             right_panel = widgets.VBox(
-                        children=[
-                            self.time_window_controller,
-                            self.fig,
-                            self.show_legend_cb
-                        ],
-                        layout=Layout(width="100%")
-                    )
+                children=[
+                    self.time_window_controller,
+                    self.fig,
+                    self.show_legend_cb
+                ],
+                layout=Layout(width="100%")
+            )
 
         if foreign_group_and_sort_controller:
             self.children = [right_panel]
         else:
             self.children = [
-                    self.gas,
-                    right_panel
-                ]
+                self.gas,
+                right_panel
+            ]
 
         self.layout = Layout(width="100%")
 
@@ -733,7 +739,7 @@ class RasterWidgetPlotly(widgets.HBox):
     def update_fig(self, change):
         time_window = self.time_window_controller.value
         gas_kwargs = self.gas.value
-        with Peakaboo(self.children[1], 1):
+        with self.fig.batch_update():
             self.fig.data = None
             show_session_raster_plotly(self.units, self.fig, time_window, **gas_kwargs)
 
@@ -775,12 +781,16 @@ def show_session_raster_plotly(units: Units, fig, time_window=None, order=None,
     for unit in this_iter:
         data.append(get_spike_times(units, unit, time_window))
 
-    #if show_obs_intervals:
+    # if show_obs_intervals:
     #    unobserved_intervals_list = get_unobserved_intervals(units, time_window, order)
-    #else:
+    # else:
     #    unobserved_intervals_list = None
 
     fig.update_yaxes(tickvals=[], ticktext=[])
+    if len(order) <= 100:
+        kwargs.update(marker='line-ns', line_width=2)
+    else:
+        kwargs.update(line_width=1)
     fig = plot_grouped_events_plotly(data=data, fig=fig, **kwargs)
     if len(order) <= 40:
         fig.update_yaxes(tickvals=np.arange(len(order)), ticktext=[str(i) for i in order])
@@ -790,6 +800,6 @@ def show_session_raster_plotly(units: Units, fig, time_window=None, order=None,
         xaxis_title="time (s)",
         legend=dict(x=1., y=0, traceorder='reversed'),
         xaxis=dict(range=time_window),
-        yaxis=dict(range=[-.5, len(order)+.5]))
+        yaxis=dict(range=[-.5, len(order) + .5]))
 
-    return fig
\ No newline at end of file
+    return fig
