@@ -1,21 +1,20 @@
-import pynwb
-import ndx_grayscalevolume
 from collections import OrderedDict
-from nwbwidgets import behavior, misc, base, ecephys, image, ophys, icephys, timeseries, file
-import hdmf
-from ndx_icephys_meta.icephys import SweepSequences
-from ipywidgets import widgets
-from .ecephys import ElectrodesWidget
-from .base import render_dataframe
+
 import h5py
+import hdmf
+import ndx_grayscalevolume
+import pynwb
 import zarr
+from ipywidgets import widgets
+from ndx_icephys_meta.icephys import SweepSequences
+from nwbwidgets import behavior, misc, base, ecephys, image, ophys, icephys, timeseries, file
 
 
 # def show_dynamic_table(node: DynamicTable, **kwargs):
 def show_dynamic_table(node, **kwargs) -> widgets.Widget:
     if node.name == 'electrodes':
-        return ElectrodesWidget(node)
-    return render_dataframe(node)
+        return ecephys.show_electrodes(node)
+    return base.render_dataframe(node)
 
 
 default_neurodata_vis_spec = {
@@ -33,9 +32,9 @@ default_neurodata_vis_spec = {
     pynwb.ophys.ImagingPlane: base.show_fields,
     pynwb.ecephys.SpikeEventSeries: ecephys.show_spike_event_series,
     pynwb.ophys.ImageSegmentation: ophys.show_image_segmentation,
-    pynwb.ophys.TwoPhotonSeries: ophys.show_two_photon_series,
+    pynwb.ophys.TwoPhotonSeries: ophys.TwoPhotonSeriesWidget,
     ndx_grayscalevolume.GrayscaleVolume: ophys.show_grayscale_volume,
-    pynwb.ophys.PlaneSegmentation: ophys.show_plane_segmentation,
+    pynwb.ophys.PlaneSegmentation: ophys.route_plane_segmentation,
     pynwb.ophys.DfOverF: ophys.show_df_over_f,
     pynwb.ophys.RoiResponseSeries: ophys.RoiResponseSeriesWidget,
     pynwb.misc.AnnotationSeries: OrderedDict({
@@ -50,15 +49,18 @@ default_neurodata_vis_spec = {
         'over time': timeseries.SeparateTracesPlotlyWidget,
         'trace': behavior.plotly_show_spatial_trace}),
     pynwb.image.GrayscaleImage: image.show_grayscale_image,
-    pynwb.image.RGBImage: image.show_rbg_image,
+    pynwb.image.RGBImage: image.show_rbga_image,
+    pynwb.image.RGBAImage: image.show_rbga_image,
+    pynwb.base.Image: image.show_rbga_image,
     pynwb.image.ImageSeries: image.show_image_series,
     pynwb.image.IndexSeries: image.show_index_series,
     pynwb.TimeSeries: timeseries.show_timeseries,
+    pynwb.core.NWBContainer: base.show_neurodata_base,
     pynwb.core.NWBDataInterface: base.show_neurodata_base,
     h5py.Dataset: base.show_dset,
     zarr.core.Array: base.show_dset
 }
 
 
-def nwb2widget(node,  neurodata_vis_spec=default_neurodata_vis_spec):
+def nwb2widget(node, neurodata_vis_spec=default_neurodata_vis_spec):
     return base.nwb2widget(node, neurodata_vis_spec)
